
# Installation and Configuration of CentOS7 Diskless OS for armv7

## Host packages to install:
* nfs-utils, tftp-server

## Download and unpack distibution script
* [github armv7-rc1](https://github.com/JeffersonLab/centos7_dist/archive/armv7-rc1.tar.gz)
* e.g.


## Download tgz's from coda website
[Coda CentOS7](https://coda.jlab.org/drupal/content/centos7)
* put them in the `tgz` directory

## diskless_gen.sh configuration file
* Minimal options to complete in the `diskless.cfg`

### `CLIENT_HOSTNAME[n]`
* Bash array of client hostnames
* Start with element 0, and increase by 1 for each client
* Example
```
CLIENT_HOSTNAME[0]=rocvtp1
```
### VTP_MAC_ADDR
* This parameter is used in the generation of the VTPs environment file.
* The MAC address is unique for each VTP, and can be obtained from Ben Raydo.
* Example
```
VTP_MAC_ADDR="ce:ba:f0:03:cc:ff"
```


### `TGZ_TFTP` and `TGZ_ROOT`
* Paths to distribution files.  The names here will change depending on the release version.

## Install everything.
```
diskless_gen.sh -E
```

## Enable the NFS-server service
```
systemctl enable nfs-server.service
```

## Enable the TFTP server
* Enable
```
systemctl enable tftp
```

## Client Configuration
* Generate the VTP's U-boot environment
```
diskless_gen.sh -e
```
* Copy the resulting file (`output/env.bin`) to the VTPs microSD FAT partition.


## Unpack distribution
* tftp kernel boot files
```
diskless_gen.sh -b
```
* root filesystem
```
diskless_gen.sh -r
```
    * this also generates the base snapshot directory `NFS_SNAPSHOT_PATH` and `NFS_HOME_PATH` if they do not already exist


## NFS Configuration
* [RHEL7: CONFIGURING THE NFS SERVER](https://access.redhat.com/documentation/en-us/red_hat_enterprise_linux/7/html/storage_administration_guide/nfs-serverconfig)

* Two options
    1. Per Client Configuration using the script
```
diskless_gen.sh -n
```
	generates this output:
```
/diskless/CentOS7/armhfp/root dafarm18(rw,no_root_squash,async) dafarm10(rw,no_root_squash,async)
/diskless/CentOS7/armhfp/snapshot dafarm18(rw,no_root_squash,async) dafarm10(rw,no_root_squash,async)
/diskless/CentOS7/armhfp/home dafarm18(rw,no_root_squash,async) dafarm10(rw,no_root_squash,async)
```

	2. Configure for subnet by hand
```
/diskless/CentOS7/armhfp/root 192.168.1.0/24(rw,no_root_squash,async)
/diskless/CentOS7/armhfp/snapshot 192.168.1.0/24(rw,no_root_squash,async)
/diskless/CentOS7/armhfp/home 192.168.1.0/24(rw,no_root_squash,async)
```


* Verify mount, if enabled for subnet:
```
cd /mnt
mkdir testmount
mount $HOSTNAME:/usr/local/diskless/CentOS7/armhfp/root testmount
```


* client snapshot
```
./diskless_gen.sh -s
```
* generate and install yp.conf, home.autofs, readonly-root
```
./diskless_gen.sh -u
```
