# diskless_gen.sh

This script is intended to assist with the installation and
configuration of the files and services required to support a diskless
CentOS7 environment for CODA readout components (e.g. VME Controllers
and VTPs).

## Files and Directories

* diskless_gen.sh
  - Script to configure and install the diskless OS

* diskless.cfg
  - Default configuration file provided as a good starting point

* templates/
  - Directory with template files for generating:
	* /etc/auto.master.d/home.autofs
	* /etc/sysconfig/readonly-root
	* /etc/yp.conf
	* pxelinux.cfg configuration files

* output/
  - Directory where generated files will be placed before installation.

## diskless_gen.sh Usage

```
 diskless_gen.sh generates and installs configuration files for diskless OS

Examples:
   diskless_gen.sh         # generate and install all diskless config files
   diskless_gen.sh daroc1  # generate and install client config files
                           #  for client with hostname 'daroc1'
   diskless_gen.sh -g      # generate config files without installation
                           #  output into $OUTPUT_PATH


Output/install Options:

   -g                         generate config files without installation
   -o                         install the config files in OUTPUT_PATH

Config file Option:

   -f FILE                    Use FILE for configuration file definitions
      			      (default diskless.cfg)

Host Specific Options:

   -p                         pxelinux.cfg setup only
   -n			      NFS setup only
   -b                         extract and install TGZ_TFTP only
   -r			      extract and install TGZ_ROOT only
   -d			      when extracting TGZ, delete older PXE_KERNEL_PATH
   			       or NFS_ROOT_PATH already exists.

Client OS Options
   -u                         generated (and install) yp.conf, home.autofs, readonly-root
   			      for Client's OS
   -j			      Remove the jlab network specific additions (yp.conf, jlab.autofs)

Client Specific Options:

   -c                         process only the client config files
   			      (pxelinux.cfg address files, snapshot)
   -s			      generate only the snapshot directories

Help Options:

   -v                         verbose output
   -l			      verbose and colored output
   -h			      give this help list
```

## config file definitions
```
   OUTPUT_PATH                # Where to output generated config files

   CLIENT_HOSTNAME[0]         # Bash array of client hostnames
   CLIENT_HOSTNAME[1]
   ...
   CLIENT_HOSTNAME[n]

   NFS_SERVER_HOSTNAME        # Hostname of NFS server
   NFS_PATH                   # Local base PATH for NFS exports (root, home, and snapshot)
   NFS_ROOT_PATH              # root PATH
   NFS_SNAPSHOT_PATH	      # snapshot PATH
   NFS_HOME_PATH              # home PATH

   TFTP_PXELINUX_CFG_PATH     # Local base PATH for tftp pxelinux.cfg directory
   TFTP_PXELINUX_CFG_DEFAULT  # Filename of default file in pxelinux.cfg
   PXE_KERNEL_PATH            # Local PATH of boot kernel files

   TEMPLATE_PATH              # PATH For diskless_gen.sh template files
   YP_CONF_TEMPLATE           # yp.conf template
   READONLY_ROOT_TEMPLATE     # readonly-root template
   PXECONFIG_ADDR_TEMPLATE    # pxelinux.cfg address file template
   AUTOFS_HOME_TEMPLATE       # home.autofs template

   CLIENTSTATE                # Mount point for snapshot directory (NFS or local)

   TGZ_TFTP                   # kernel boot file archive for tftp
   TGZ_ROOT                   # OS root directory archive
```
